@@ -35,7 +35,7 @@ package Mail::SpamAssassin::AsyncLoop;
 
 use strict;
 use warnings;
-use bytes;
+# use bytes;
 use re 'taint';
 
 use Time::HiRes qw(time);
@@ -46,8 +46,8 @@ use Mail::SpamAssassin::Logger;
 our @ISA = qw();
 
 # obtain timer resolution if possible
+our $timer_resolution;
 BEGIN {
-  use vars qw($timer_resolution);
   eval {
     $timer_resolution = Time::HiRes->can('clock_getres')
       ? Time::HiRes::clock_getres(Time::HiRes::CLOCK_REALTIME())
@@ -212,6 +212,7 @@ sub start_lookup {
 
   my $t_end = $ent->{timeout_min};       # application-specified has precedence
   $t_end = $settings->{rbl_timeout_min}  if $settings && !defined $t_end;
+  $t_end = $self->{main}->{conf}->{rbl_timeout_min}  if !defined $t_end; # added for bug 7070
   $t_end = 0.2 * $t_init  if !defined $t_end;
   $t_end = 0  if $t_end < 0;  # just in case
   $t_init = $t_end  if $t_init < $t_end;
