@@ -19,8 +19,6 @@
 
 Mail::SpamAssassin::BayesStore::Redis - Redis Bayesian Storage Module Implementation
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
 This module implementes a Redis based bayesian storage module.
@@ -118,7 +116,7 @@ package Mail::SpamAssassin::BayesStore::Redis;
 
 use strict;
 use warnings;
-use bytes;
+# use bytes;
 use re 'taint';
 use Errno qw(EBADF);
 use Mail::SpamAssassin::Util qw(untaint_var);
@@ -133,12 +131,8 @@ use Mail::SpamAssassin::Logger;
 use Mail::SpamAssassin::BayesStore;
 use Mail::SpamAssassin::Util::TinyRedis;
 
-use vars qw( @ISA $VERSION );
-
-BEGIN {
-  $VERSION = 0.09;
-  @ISA = qw( Mail::SpamAssassin::BayesStore );
-}
+our $VERSION = 0.09;
+our @ISA = qw( Mail::SpamAssassin::BayesStore );
 
 =head1 METHODS
 
@@ -161,7 +155,7 @@ sub new {
   my $bconf = $self->{bayes}->{conf};
 
   foreach (split(';', $bconf->{bayes_sql_dsn})) {
-    my ($a, $b) = split('=');
+    my ($a, $b) = split(/=/, $_, 2);
     if (!defined $b) {
       warn("bayes: invalid bayes_sql_dsn config\n");
       return;
@@ -202,35 +196,38 @@ sub new {
 
 sub disconnect {
   my($self) = @_;
+  local($@, $!);
   if ($self->{connected}) {
-    local($@, $!);
     dbg("bayes: Redis disconnect");
-    $self->{connected} = 0; undef $self->{redis};
+    $self->{connected} = 0;
+    $self->{redis}->disconnect;
   }
+  undef $self->{redis};
 }
 
 sub DESTROY {
   my($self) = @_;
   local($@, $!, $_);
+  dbg("bayes: Redis destroy");
   $self->{connected} = 0; undef $self->{redis};
 }
 
 # Called from a Redis module on Redis->new and on automatic re-connect.
 # The on_connect() callback must not use batched calls!
 sub on_connect {
-  my($self, $r) = @_;
-  my $db_id = $self->{db_id} || 0;
+  my($r, $db_id, $pwd) = @_;
+  $db_id ||= 0;
   dbg("bayes: Redis on-connect, db_id %d", $db_id);
   eval {
     $r->call('SELECT', $db_id) eq 'OK' ? 1 : 0;
   } or do {
-    if ($@ =~ /\bNOAUTH\b/) {
-      defined $self->{password}
+    if ($@ =~ /^NOAUTH\b/ || $@ =~ /^ERR operation not permitted/) {
+      defined $pwd
         or die "Redis server requires authentication, no password provided";
-      $r->call('AUTH', $self->{password});
+      $r->call('AUTH', $pwd);
       $r->call('SELECT', $db_id);
     } else {
-      chomp $@; die "Redis error: $@";
+      chomp $@; die "Command 'SELECT $db_id' failed: $@";
     }
   };
   eval {
@@ -250,11 +247,14 @@ sub connect {
 
   my $err = $self->{timer}->run_and_catch(sub {
     $self->{opened_from_pid} = $$;
+    # Bug 7034: avoid a closure passing $self to $self->{redis}->{on_connect},
+    # otherwise a circular reference prevents object destruction!
+    my $db_id = $self->{db_id};
+    my $pwd = $self->{password};
     # will keep a persistent session open to a redis server
     $self->{redis} = Mail::SpamAssassin::Util::TinyRedis->new(
                        @{$self->{redis_conf}},
-                       on_connect => sub { $self->on_connect(@_) },
-                     );
+                       on_connect => sub { on_connect($_[0], $db_id, $pwd) });
     $self->{redis} or die "Error: $!";
   });
   if ($self->{timer}->timed_out()) {
